==> knative-model-6.8.0-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/SecretValueFromSourceFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.SecretKeySelector;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SecretValueFromSourceFluent<A extends SecretValueFromSourceFluent<A>> extends BaseFluent<A>{
  public SecretValueFromSourceFluent() {
  }
  public SecretValueFromSourceFluent(SecretValueFromSource instance) {
    instance = (instance != null ? instance : new SecretValueFromSource());

    if (instance != null) {
      this.withSecretKeyRef(instance.getSecretKeyRef());
      this.withSecretKeyRef(instance.getSecretKeyRef());
    }
  }
  private SecretKeySelector secretKeyRef;
  public SecretKeySelector getSecretKeyRef() {
    return this.secretKeyRef;
  }
  public A withSecretKeyRef(SecretKeySelector secretKeyRef) {
    this.secretKeyRef=secretKeyRef; return (A) this;
  }
  public boolean hasSecretKeyRef() {
    return this.secretKeyRef != null;
  }
  public A withNewSecretKeyRef(String key,String name,Boolean optional) {
    return (A)withSecretKeyRef(new SecretKeySelector(key, name, optional));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretValueFromSourceFluent that = (SecretValueFromSourceFluent) o;
    if (!java.util.Objects.equals(secretKeyRef, that.secretKeyRef)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretKeyRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretKeyRef != null) { sb.append("secretKeyRef:"); sb.append(secretKeyRef); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/SecretValueFromSourceFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.SecretKeySelector;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SecretValueFromSourceFluent<A extends SecretValueFromSourceFluent<A>> extends BaseFluent<A>{
  public SecretValueFromSourceFluent() {
  }
  
  public SecretValueFromSourceFluent(SecretValueFromSource instance) {
    this.copyInstance(instance);
  }
  private SecretKeySelector secretKeyRef;
  
  protected void copyInstance(SecretValueFromSource instance) {
    instance = (instance != null ? instance : new SecretValueFromSource());
  
    if (instance != null) {
        this.withSecretKeyRef(instance.getSecretKeyRef());
        this.withSecretKeyRef(instance.getSecretKeyRef());
      }
  }
  
  public SecretKeySelector getSecretKeyRef() {
    return this.secretKeyRef;
  }
  
  public A withSecretKeyRef(SecretKeySelector secretKeyRef) {
    this.secretKeyRef=secretKeyRef; return (A) this;
  }
  
  public boolean hasSecretKeyRef() {
    return this.secretKeyRef != null;
  }
  
  public A withNewSecretKeyRef(String key,String name,Boolean optional) {
    return (A)withSecretKeyRef(new SecretKeySelector(key, name, optional));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretValueFromSourceFluent that = (SecretValueFromSourceFluent) o;
    if (!java.util.Objects.equals(secretKeyRef, that.secretKeyRef)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(secretKeyRef,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretKeyRef != null) { sb.append("secretKeyRef:"); sb.append(secretKeyRef); }
    sb.append("}");
    return sb.toString();
  }
  

}
